% DK_REIR_oil_4y.m
% Code for the paper by K. Drakos and P. Th. Konstantinou (2012)
% "Investment Decisions in Manufacturing: Assessing the Effects of Real Oil
% Prices and their Uncertainty", Journal of Applied Econometrics (forthcoming).
% The code estimates the Excess Increase Risk of Real Oil Prices, in the spirit of
% Kilian and Manganelli (2007), JMCB.
%
% Written by Panagiotis Th. Konstantinou
% Department of Economics, University of Macedonia
% Thessaloniki, Greece
% Created: September 2, 2009
% Last modified: October 8, 2009
% This follows closely (actually is based on) the codes by Kilian and Manganeli (2007), JMCB

clear all;
clc;
format long;
% warning all off;

% LOAD THE DATA
% The Original Sample runs from 1988:1 to 2005:12
% Taking differences, the actual samples might differ.
OIL_4y = load('C:\Drakos\OilUncertanityandInvestment\JAE\OIL_4y.txt');
T = length(OIL_4y);
y=OIL_4y; % The Annualized
% LT = 1;
EIR_1_mat=[];
EIR_2_mat=[];
k=1;            % The lag-length chosen by SIC/AIC/HQIC with kmax=10
[yhat, Res, BETA] = LagRegression(y, k);
y = y(k+1:T);
T=length(y);
% [LB, LBpvalue] = LjungBox(Res);
% [LB2, LBpvalue2] = LjungBox(Res.^2);
LBpvalue2 = 0.461; % p-value from eviews on Squared Residuals. ARCH(12) test gives similar results.
for UT=0.05:0.05:0.40; % Upper threshold for Oil Price Increase (*100 -> in percent)
    % THIS IS WHERE CALCULATIONS START
    if LBpvalue2<0.10
        % Run the garch model
        garchOut = garchModelResults( Res, yhat, UT);
        param = garchOut.param;
        
        if param(2)+param(3)>1 | param(2)<0
            
            for i =1:length(y);
                %index1 = find(Res<LT-yhat(i)); 
                index2 = find(Res>UT-yhat(i));
                if isempty(index2); 
                    PEI=0; 
                    EIR1(i,1)=0; 
                    EIR2(i,1)=0;
                else
                    PEI=length(index2)/T;
                    EIR1(i,1)=PEI*(yhat(i)-UT+mean(Res(index2)));
                    EIR2(i,1)=PEI*((yhat(i)-UT)^2+mean(Res(index2).^2)+2*(yhat(i)-UT)*mean(Res(index2)));
                end
            end
        else
            EIR1 = garchOut.EIR1;
            EIR2 = garchOut.EIR2;
        end
    else
        for i =1:length(y);
            index2 = find(Res>UT-yhat(i));
            if isempty(index2); 
                PEI=0; 
                EIR1(i,1)=0; 
                EIR2(i,1)=0;
            else PEI=length(index2)/T;
                EIR1(i,1)=PEI*(yhat(i)-UT+mean(Res(index2)));
                EIR2(i,1)=PEI*((yhat(i)-UT)^2+mean(Res(index2).^2)+2*(yhat(i)-UT)*mean(Res(index2)));
            end 
        end
    end
    EIR_1_mat=[EIR_1_mat;EIR1];
    EIR_2_mat=[EIR_2_mat;EIR2];
end
EIR_1=reshape(EIR_1_mat,length(y),8);
EIR_2=reshape(EIR_2_mat,length(y),8);
clear EIR_1_mat EIR_1_mat;

xlswrite('DK_OIL_4y_EIR_1.xlsx',EIR_1);
xlswrite('DK_OIL_4y_EIR_2.xlsx',EIR_2);
wk1write('DK_OIL_4y_EIR_1.wk1',EIR_1);
wk1write('DK_OIL_4y_EIR_2.wk1',EIR_2);