% DK_oil_4y_level_boot.m
% Code for the paper by K. Drakos and P. Th. Konstantinou (2012)
% "Investment Decisions in Manufacturing: Assessing the Effects of Real Oil
% Prices and their Uncertainty", Journal of Applied Econometrics (forthcoming).
%
% The code is used to create upside risk measures of Real Oil Prices, as
% described for instance in Alquist et al (2011) "Forecasting the Price of
% Oil", Board of Governors of the Federal Reserve System, International
% Finance Discussion Papers, Nr. 1022/ July 2011.
% Written by Panagiotis Th. Konstantinou
% Department of Economics, University of Macedonia
% Thessaloniki, Greece
% Created: August 1, 2011
% Last modified: January 20, 2012


clear all;
clc;
format long;
% warning all off;

% LOAD THE DATA
% The Original Sample runs from 1988:1 to 2005:12
% Taking differences, the actual samples might differ.
ROIL = load('C:\Drakos\OilUncertanityandInvestment\JAE\ROIL.txt');
T = length(ROIL);
nboot=5000;
% LT = 1;
UR_0_mat=[];
UR_1_mat=[];
UR_2_mat=[];
k=48;            % lags to define oil price change
y=log(ROIL);
dyk =log(ROIL(k+1:T)) - log(ROIL(1:T-k));
m = mean(dyk);
dykm = dyk - m;
rand('seed',10000);
Teff=length(dyk);
for UT=40:10:80; % Upper threshold for Real Oil Prices (in 2005 euros)
    Rstar=[];
    for j=1:nboot;
        index=ceil(rand(Teff,1)*(Teff-1));
        dykstar=[zeros(k,1); dykm(index)];
        ystar=zeros(T,1);
        ystar(1:k,1) = y(1:k,1);     % Initial conditions given
        for t=1:Teff;
            ystar(t+k)= m + dykstar(t+k)+y(t);
        end
        Ystar=exp(ystar);
        Rstar=[Rstar,Ystar(k+1:k+Teff,1)];
    end
    M=Rstar-UT;
    V=(Rstar-UT).^2;
    clear t;
    for t=1:Teff;
        index_up = find(Rstar(t,:)-UT>0);
        if isempty(index_up); 
            UR0(t,1)=0; 
            UR1(t,1)=0; 
            UR2(t,1)=0;
        else
            UR0(t,1) = length(find(Rstar(t,:)-UT>0))/nboot;
            UR1(t,1) = UR0(t,1)*mean(M(t,[index_up]),2);
            UR2(t,1) = UR0(t,1)*mean(V(t,[index_up]),2);
        end
    end
    clear Rstar M V index dykstar ystar Ystar index_up;
    UR_0_mat=[UR_0_mat,UR0];
    UR_1_mat=[UR_1_mat,UR1];
    UR_2_mat=[UR_2_mat,UR2];
end
    
        
xlswrite('ROIL_4y_UR_0.xls',UR_0_mat);
xlswrite('ROIL_4y_UR_1.xls',UR_1_mat);
xlswrite('ROIL_4y_UR_2.xls',UR_2_mat);