function rse = garch11robustStdErr(param,data)
% function rse = garch11r(param,data)
%
%  This program calculates the robust standard errors for the 
%  GARCH(1,1) model as per Bollerslev & Wooldridge.
%
%  Input: param = (4x1) vector [mu w alpha beta]
%         data = (Tx1) vector over which parameters estimated
%  Output: rse = (4x1) vector of robust standard errors

T = length(data);
%mu = param(1)
w = param(1);
alpha = param(3);
beta = param(2);
%pause

rse = zeros(3,1);
e = data;%-mu;
e2 = e.^2;
h = zeros(T,1);
A = zeros(3,3);
B = zeros(3,3);
score = zeros(1,3);
hess = zeros(3,3);

LAMBDA    = 0.7;
expsmooth = LAMBDA .^ [0: 1 : T-1] * data .^ 2;
h(1)      = LAMBDA ^ T * (data'*data/T) + (1-LAMBDA) * expsmooth;

%dmu = [1 0 0 0]';
%dmudmu = dmu*dmu';
dhw = 0; dhalpha = 0; dhbeta = 0;
for t = 2:T
	h(t) = w + alpha * e2(t-1) + beta * h(t-1);
	%dh = [1 e2(t-1) h(t-1)];
    dhw = 1 + beta * dhw;
    dhalpha = e2(t-1) + beta * dhalpha;
    dhbeta = h(t-1) + beta*dhbeta;
    dh = [dhw, dhalpha, dhbeta];
    
	score = (dh/2) * ((e2(t)-h(t))/(h(t)^2));
	B = B + score'*score;
	hess = (dh'*dh) / (2*(h(t)^2));
	A = A + hess;
end;
%flag =1 
%pause
B = B/T;
A = A/T;
var = inv(A)*B*inv(A)/T;
rse = sqrt(diag(var));

