#include "mex.h"
#include "math.h"

/* C loop to compute the likelihood for a Normal GARCH(1,1).
 * The program takes as input the vector of returns (y) and the parameter GAMMA 
 * and produces as output the value of the likelihood.
 */

void ComputeGARCH(double GAMMA[], double y[], double sigma2, double lik[], int RowsOfy)

{
	int i;
	double pi;
	pi = 3.14159265358979;
	
	/* Initialize sigma2 */
	lik[0] = .5 * (log(2*pi) + log(sigma2) + y[0] * y[0]/sigma2);

	/* Start the loop */
	for(i = 1; i < RowsOfy; i++)
		{
			sigma2 = GAMMA[0] + GAMMA[1] * sigma2 + GAMMA[2] * y[i-1] * y[i-1];

			if (sigma2<=0 | sigma2>pow(10,100))
			{
				lik[0] = pow(10,308);
				break;
				}
				
         /*else lik[i] = 30; */
         lik[0] = lik[0] + .5*(log(2*pi) + log(sigma2) + y[i]*y[i]/sigma2);
		}
		
}


/***********************************************/

/* The gateway function */

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	double *y, *GAMMA, *lik;
	double sigma2;
	int RowsOfy;

	/* Check for proper number of arguments */
	if (nrhs != 3)
		mexErrMsgTxt("Three inputs required.");
	if (nlhs!=1)
		mexErrMsgTxt("One output required.");

	/* Check appropriate form of other inputs
		.......
	 */

	/* Create a pointer to the input vectors GAMMA and y */
	GAMMA = mxGetPr(prhs[0]);
	y = mxGetPr(prhs[1]);
	sigma2 = mxGetScalar(prhs[2]);

	/* Get the dimension of y */
	RowsOfy = mxGetM(prhs[1]);

	/* Set the output pointer */
	plhs[0] = mxCreateDoubleMatrix(1, 1, mxREAL);

	/* Create a C pointer to a copy of the output vectors */
	lik = mxGetPr(plhs[0]);

	/* Call the C subroutine */
   ComputeGARCH(GAMMA, y, sigma2, lik, RowsOfy);

}
