function results = garchModelResults(u, yhat, UT)
%
% Estimate a GARCH(1,1) model (with robust standard errors and LB statistics) and computes the upside risk indices
% INPUT:    u     = vector of residuals from the regression model
%           yhat  = OLS regression estimates 
% OUTPUT:   parameter estimates (\omega, \alpha, \beta)
%           Excess Increase Risk 1
%           Excess Increase Risk 2
%
% WRITTEN:  by Simone Manganelli
% MODIFIED: by Panagiotis Th. Konstantinou, for the purposes of the paper
% K. Drakos and P. Konstantinou (2011) "Investment Decisions of Manufacturing
% Plants: Investigating State-Dependence and Oil Uncertainty Effects"

T = length(u);

% Estimate the Garch(1,1) model.
f = garch(u);

param = f.theta;
stdErr = sqrt(f.variance); 
%variance = f.variance;
% VAR4cast = [1, variance(T), u(T)^2] * param;

% *************************************************************************
% STEP 1 - Specification tests for the GARCH model.
% 1. Compute standard errors.
% NOTE: In order to use this use the appropriate function from Kilian and
% Manganelli (2007), JMCB
%rse = garch11robustStdErr(param, u);
stdRes = u./stdErr;

% 2. Ljung-Box statistic.
%[LBstd, LBpvaluestd] = LjungBox(stdRes);
%[LBstd2, LBpvaluestd2] = LjungBox(stdRes.^2);

% *************************************************************************
% STEP 2 - Compute the Excess Increase of Oil Price Risks.

for i = 1:T
    index = find(stdRes>(UT-yhat(i))/stdErr(i));
    if isempty(index); 
        PEI=0; 
        EIR(i,1)=0; 
    else
        PEI=length(index)/length(yhat);
        %PEII(i,1)=length(index)/length(yhat);
        EIR1(i,1)=PEI*(yhat(i)-UT+stdErr(i)*mean(stdRes(index)));
        EIR2(i,1)=PEI*((yhat(i)-UT)^2+(stdErr(i)^2)*(mean(stdRes(index).^2))+2*(yhat(i)-UT)*stdErr(i)*mean(stdRes(index)));
    end
    
end

results.param = param;
%results.rse = rse;
results.EIR1 = EIR1;
results.EIR2 = EIR2;
% results.LBstd = LBstd;
% results.LBpvaluestd = LBpvaluestd;
% results.LBstd2 = LBstd2;
% results.LBpvaluestd2 = LBpvaluestd2;
% results.PEII=PEII;