function [Yhat, Res, BETA] = LagRegression(X, LAG)

% Construct the regressors from the lagged variables given in input and compute OLS estimates, fitted values and residuals.
%
% INPUT: X   = (T,K)-matrix (dependent variable in the first column, additional regressors in the other columns)
%        LAG = number of lag regressors to be constructed from the X matrix
%
% OUTPUT:

[T,K] = size(X);
Z = ones(T-LAG, 1+K*LAG);

Y = X(LAG+1:T,1);
for i = 1:K
    for j = 1:LAG
        Z(:,j+LAG*(i-1)) = X(j:T-LAG-1+j, i);
    end
end

BETA = inv(Z'*Z) *(Z'*Y);
Yhat = Z*BETA;
Res  = Y-Yhat;