function [LB, LBpvalue] = LjungBox(u)

% Compute the Ljung-Box test of autocorrelation for the first 12 lags.
%
% INPUT:  u = (T,1)-vector of residuals
%
% OUTPUT: LB = Ljung-Box statistic
%         LBpvalue = p-value of the LB statistic
LAGS = 12;
T = length(u);
uMEAN = mean(u);
TAU = zeros(LAGS,1); LB = 0;
for ai = 1:LAGS
    TAU(ai) = (u(LAGS+1:T)-uMEAN)' * (u(ai:T-(LAGS+1)+ai)-uMEAN)/(T*var(u));
    LB = LB + TAU(ai)^2/(T-(LAGS+1)+ai);
end
LB = T*(T+2)*LB;
LBpvalue = 1-chi2cdf(LB,LAGS+1);